@@ -145,6 +145,13 @@ setMethod("TSdelete", signature(serIDs="character", con="TSodbcConnection"),
      vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
    TSdbi:::TSdeleteSQL(serIDs=serIDs, con=con, vintage=vintage, panel=panel) )
 
+setMethod("TSvintages", 
+   signature(con="TSodbcConnection"),
+   definition=function(con) {
+     if(!con@hasVintages) NULL else   
+     dbGetQuery(con,"SELECT  DISTINCT(vintage) FROM  vintages;" )$vintage
+     } )
+
 setMethod("dropTStable", 
    signature(con="RODBC", Table="character", yesIknowWhatIamDoing="ANY"),
    definition= function(con=NULL, Table, yesIknowWhatIamDoing=FALSE){
